@@ -1,4 +1,4 @@
-from pims_api_client.schemas import AttributeFilter, AttributeListItem
+from pims_api_client.schemas import AttributeFilter, AttributeListItem, BaseAttribute
 from pims_api_client.schemas import PagedListResponse
 from typing import Optional
 from .base_executor import BaseExecutor
@@ -12,3 +12,6 @@ class AttributeMethodsExecutor(BaseExecutor):
     async def fetch_attribute(self, uid: str):
         response = await self.client.get(f'pim/api/v1/attribute/{uid}')
         return AttributeListItem.parse_obj(response)
+
+    async def create_attribute(self, data: BaseAttribute):
+        return await self.client.post('pim/api/v1/attribute', data=data.dict())
\ No newline at end of file
