@@ -11,20 +11,23 @@ class AttributeFilter(PerPageRequest):
         allow_population_by_field_name = True
 
 
-class AttributeListItem(BaseModel):
-    id: str
-    group: dict
-    value: dict
+class BaseAttribute(BaseModel):
     name: str
     type: str
-    type_translation: str
     code: str
+    group: str
     is_required: bool
     is_editable: bool
     is_filterable: bool
     is_visible: bool
     position: int
 
+class AttributeListItem(BaseAttribute):
+    id: str
+    value: dict
+    group: dict
+    type_translation: str
+
 
 class AttributeGroupItem(BaseModel):
     id: str
